@@ -16,11 +16,6 @@ has 'location' => (
     is       => 'ro',
     isa      => 'Maybe[Str]',
     required => 0,
-    lazy     => 1,
-
-    # https://docs.aws.amazon.com/AmazonS3/latest/API/RESTBucketPUT.html
-    # "By default, the bucket is created in the US East (N. Virginia) region."
-    default  => sub { 'us-east-1' },
 );
 
 has '+_expect_nothing' => ( default => 1 );
@@ -28,11 +23,16 @@ has '+_expect_nothing' => ( default => 1 );
 sub request {
     my $s = shift;
 
-    my $xml = <<"XML";
+    # By default the bucket is put in us-east-1. But if you _ask_ for
+    # us-east-1 you get an error.
+    my $xml = q{};
+    if ( $s->location && $s->location ne 'us-east-1' ) {
+        $xml = <<"XML";
 <CreateBucketConfiguration xmlns="http://s3.amazonaws.com/doc/2006-03-01/"> 
-  <LocationConstraint>@{[ $s->location || 'us-east-1' ]}</LocationConstraint> 
+  <LocationConstraint>@{[ $s->location ]}</LocationConstraint>
 </CreateBucketConfiguration>
 XML
+    }
 
     my $signer = AWS::S3::Signer->new(
         s3           => $s->s3,
